@@ -12,7 +12,7 @@ $null=Image::Magick->new;
 $null->Set(size=>'70x70');
 $x=$null->ReadImage('NULL:black');
 warn "$x" if "$x";
-$model=Image::Magick->new;
+$model=Image::Magick->new();
 $x=$model->ReadImage('model.gif');
 warn "$x" if "$x";
 $model->Label('Magick');
@@ -27,7 +27,7 @@ $smile->Set(bordercolor=>'black');
 # Create image stack.
 #
 print "Transform image...\n";
-$images=Image::Magick->new;
+$images=Image::Magick->new();
 $example=$null->Clone();
 push(@$images,$example);
 $example=$null->Clone();
@@ -39,13 +39,18 @@ push(@$images,$example);
 $example=$null->Clone();
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Add Noise');
+$example->AddNoise("LaplacianNoise");
+push(@$images,$example);
+$example=$model->Clone();
+$example=$model->Clone();
 $example->Label('Annotate');
-$example->Annotate(text=>'Magick',geometry=>'+0+10',font=>'@Generic.ttf',
-  pen=>'gold',gravity=>'North');
+$example->Annotate(text=>'Magick',geometry=>'+0+20',font=>'@Generic.ttf',
+  fill=>'gold',gravity=>'North',pointsize=>14);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Blur');
-$example->Blur(60);
+$example->Blur(3);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Border');
@@ -53,13 +58,21 @@ $example->Border(color=>'gold');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Charcoal');
-$example->Charcoal();
+$example->Charcoal(3);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Composite');
 $example->Composite(image=>$smile,compose=>'over',geometry=>'+35+65');
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Contrast');
+$example->Contrast();
+push(@$images,$example);
+$example=$model->Clone();
+$example->Label('Convolve');
+$example->Convolve([1, 1, 1, 1, 4, 1, 1, 1, 1]);
+push(@$images,$example);
+$example=$model->Clone();
 $example->Label('Crop');
 $example->Crop(geometry=>'80x80+25+50');
 push(@$images,$example);
@@ -69,12 +82,16 @@ $example->Despeckle();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Draw');
-$example->Draw(pen=>'gold',primitive=>'circle',points=>'60,90 60,120',
+$example->Draw(stroke=>'gold',primitive=>'circle',points=>'60,90 60,120',
   linewidth=>2);
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Detect Edges');
+$example->Edge(3);
+push(@$images,$example);
+$example=$model->Clone();
 $example->Label('Emboss');
-$example->Emboss();
+$example->Emboss(3);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Equalize');
@@ -82,6 +99,7 @@ $example->Equalize();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Explode');
+$example->Set(background=>'#00000000');
 $example->Implode(-10);
 push(@$images,$example);
 $example=$model->Clone();
@@ -100,6 +118,10 @@ $example=$model->Clone();
 $example->Label('Gamma');
 $example->Gamma(1.6);
 push(@$images,$example);
+$example=$model->Clone();
+$example->Label('Gaussian Blur');
+$example->GaussianBlur("2x2");
+push(@$images,$example);
 $gradation=Image::Magick->new;
 $gradation->Set(size=>'130x194');
 $x=$gradation->ReadImage('gradation:#20a0ff-#ffff00');
@@ -115,6 +137,10 @@ $example->Label('Implode');
 $example->Implode(30);
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Median Filter');
+$example->MedianFilter();
+push(@$images,$example);
+$example=$model->Clone();
 $example->Label('Modulate');
 $example->Modulate(brightness=>-3,saturation=>-3,hue=>-3);
 push(@$images,$example);
@@ -145,6 +171,11 @@ $example->Label('Raise');
 $example->Raise();
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Reduce Noise');
+$example->ReduceNoise(order=>3);
+push(@$images,$example);
+$example=$model->Clone();
+$example=$model->Clone();
 $example->Label('Roll');
 $example->Roll(geometry=>'+20+10');
 push(@$images,$example);
@@ -154,6 +185,10 @@ $example->Rotate(45);
 $example->Transparent(color=>'black');
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Scale');
+$example->Scale('60%');
+push(@$images,$example);
+$example=$model->Clone();
 $example->Label('Segment');
 $example->Segment();
 push(@$images,$example);
@@ -163,7 +198,7 @@ $example->Shade(geometry=>'30x30',color=>'false');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Sharpen');
-$example->Sharpen(60);
+$example->Sharpen(3);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Shear');
@@ -179,11 +214,13 @@ $example->Label('Solarize');
 $example->Solarize();
 push(@$images,$example);
 $example=$model->Clone();
+$example->Set(background=>'#00000000');
 $example->Label('Swirl');
 $example->Swirl(90);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Wave');
+$example->Set(background=>'#00000000');
 $example->Wave('25x150');
 push(@$images,$example);
 $example=$model->Clone();
@@ -191,32 +228,18 @@ $example->Label('Zoom');
 $example->Zoom('50%');
 push(@$images,$example);
 #
-# Create title.
-#
-print "Annotate image...\n";
-$background=Image::Magick->new;
-$background->Set(size=>'550x90');
-$x=$background->ReadImage('gradation:#20a0ff-#ffff00');
-warn "$x" if "$x";
-$title=Image::Magick->new;
-$title->Set(size=>'550x90');
-$x=$title->ReadImage('xc:black');
-warn "$x" if "$x";
-$title->Annotate(text=>'PerlMagick',geometry=>"+1+1",font=>'@Generic.ttf',
-  pointsize=>18,density=>'300x300',pen=>'white',gravity=>'center');
-$title->Draw(primitive=>'Matte',points=>'+0+0',method=>'Replace',pen=>'black');
-$title->Composite(image=>$background,compose=>'Add');
-#
 # Create image montage.
 #
 print "Montage image...\n";
-$montage=$images->montage(filename=>'PerlMagick',geometry=>'130x194+10+5>',
+$montage=$images->Montage(filename=>'PerlMagick',geometry=>'130x194+10+5>',
   gravity=>'Center',bordercolor=>'green',borderwidth=>1,tile=>'5x1000',
-  compose=>'over',texture=>'granite:',font=>'@Generic.ttf',pen=>'#600');
-$montage->Composite(image=>$title,geometry=>'+90+50',compose=>'Over');
-$montage->Annotate(text=>'Every thing you see on this page was created ' .
-  'with the PerlMagick and ImageMagick toolkits.',geometry=>"+20+175",
-  font=>'@Generic.ttf',pointsize=>11,pen=>'#600');
+  compose=>'over',background=>'#ffffff',font=>'@Generic.ttf',pointsize=>18,
+  fill=>'#600');
+$logo=Image::Magick->new();
+$logo->Read('logo:');
+$logo->Crop('461x455+98+0');
+$logo->Zoom('45%');
+$montage->Composite(image=>$logo,geometry=>'+245+0',compose=>'Over');
 print "Write image...\n";
 $montage->Set(matte=>'false');
 $montage->Write('demo.jpg');
